summaryrefslogtreecommitdiff
path: root/src/lg_hwcurs.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/lg_hwcurs.c')
-rw-r--r--src/lg_hwcurs.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lg_hwcurs.c b/src/lg_hwcurs.c
index 4012db0..20ac38a 100644
--- a/src/lg_hwcurs.c
+++ b/src/lg_hwcurs.c
@@ -166,12 +166,12 @@ static void LgLoadCursorImage(ScrnInfoPtr pScrn, unsigned char *bits)
LgSETMODE(HOST2SCR); /* Host-to-screen blit */
LgSETROP(0x00CC); /* Source copy */
/* First, copy our transparent cursor image to the next 1/2 tile boundry */
/* Destination */
LgSETMDSTXY(pLg->HWCursorImageX+pLg->HWCursorTileWidth, pLg->HWCursorImageY);
/* Set the source pitch. 0 means that, worst case, the source is
- alligned only on a byte boundry */
+ aligned only on a byte boundary */
LgSETMPHASE1(0);
LgSETMEXTENTSNOMONOQW(pLg->HWCursorTileWidth, pLg->HWCursorTileHeight);
@@ -191,7 +191,7 @@ static void LgLoadCursorImage(ScrnInfoPtr pScrn, unsigned char *bits)
LgSETMDSTXY(pLg->HWCursorImageX, pLg->HWCursorImageY);
/* Set the source pitch. 0 means that, worst case, the source is
- alligned only on a byte boundry */
+ aligned only on a byte boundary */
LgSETMPHASE1(0);
/* Always copy an entire cursor image to the card. */
@@ -264,7 +264,7 @@ LgFindCursorTile(ScrnInfoPtr pScrn, int *x, int *y, int *width, int *height,
if (PCI_CHIP_GD5465 == pCir->Chipset) {
/* The Where's The Cursor formula changed for the 5465. It's really
- kinda wierd now. */
+ kinda weird now. */
unsigned long page, bank;
unsigned int nX, nY;
@@ -166,12 +166,12 @@ static void LgLoadCursorImage(ScrnInfoPtr pScrn, unsigned char *bits)
LgSETMODE(HOST2SCR); /* Host-to-screen blit */
LgSETROP(0x00CC); /* Source copy */
- /* First, copy our transparent cursor image to the next 1/2 tile boundry */
+ /* First, copy our transparent cursor image to the next 1/2 tile boundary */
/* Destination */
LgSETMDSTXY(pLg->HWCursorImageX+pLg->HWCursorTileWidth, pLg->HWCursorImageY);